==> EnbanFukusyaYa-1.19-20081107-src.tar.gz: EnbanFukusyaYa-1.19/Win32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by EnbanFukusya.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDM_THEMESELECT                 0x0020
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_ENBANFUKUSYA_DIALOG         102
#define IDS_DRIVENOTFOUND               102
#define IDS_YES                         103
#define IDS_NO                          104
#define IDS_OK                          105
#define IDS_CANCEL                      106
#define IDS_RETRY                       107
#define IDS_ABORT                       108
#define IDS_IGNORE                      109
#define IDS_COPYSTART                   110
#define IDS_PROCESS_ABORTED             111
#define IDS_PROCESS_SUCCESS             112
#define IDS_PROCESS_ERRSTOP             113
#define IDS_DRIVEINITERROR              114
#define IDS_CREATELOG_ERROR             115
#define IDS_CREATELOG_SUCCESS           116
#define IDS_THEMESELECT                 117
#define IDS_PROCESS_SUCCESS_IMAGE       118
#define IDR_MAINFRAME                   128
#define IDB_LOGO                        129
#define IDB_LOGOMASK                    130
#define IDB_AQUA_BUTTON                 131
#define IDB_AQUA_BUTTONFOCUS            132
#define IDB_AQUA_BUTTONMASK             133
#define IDB_AQUA_PROGRESSBG             134
#define IDB_AQUA_PROGRESSFG             135
#define IDB_AQUA_DROPBUTTON             136
#define IDB_AQUA_DROPBUTTONMASK         137
#define IDB_AQUA_COMBOBOXBG             138
#define IDB_AQUA_CLOSEBUTTON            139
#define IDD_MESSAGEDLG                  139
#define IDB_AQUA_CLOSEBUTTONMASK        140
#define IDB_AQUA_MAXBUTTON              141
#define IDI_APPICON                     141
#define IDB_AQUA_MINBUTTON              142
#define IDI_MSGDLG_STOP                 142
#define IDB_AQUA_TITLEACT               143
#define IDI_MSGDLG_QUESTION             143
#define IDB_AQUA_TITLEINACT             144
#define IDI_MSGDLG_EXCLAMATION          144
#define IDB_AQUA_DIALOGBG               145
#define IDD_SETTING                     145
#define IDB_AQUA_CHECKEDMASK            146
#define IDB_AQUA_CHECKED                147
#define IDB_AQUA_UNCHECKEDMASK          148
#define IDB_AQUA_UNCHECKED              149
#define IDB_BUTTON_NORMAL               150
#define IDB_UNCHECKED                   151
#define IDB_BUTTON_DISABLE              152
#define IDB_BUTTON_FOCUS                153
#define IDB_BUTTON_SELECT               154
#define IDB_CHECKED                     155
#define IDB_DIALOGBG                    157
#define IDB_DROPDOWN                    158
#define IDB_CLOSEBUTTON                 160
#define IDB_COMBOBOX                    162
#define IDB_DROPDOWN_MASK               163
#define IDB_TITLE_INACT                 166
#define IDB_TITLE_ACT                   167
#define IDB_PROGRESSFG                  168
#define IDB_PROGRESSBG                  169
#define IDD_THEMESELECTDLG              170
#define IDB_TOWADA_BUTTON               183
#define IDB_TOWADA_BUTTONFOCUS          184
#define IDB_TOWADA_BUTTONSELECT         185
#define IDB_TOWADA_CHECKED              186
#define IDB_TOWADA_UNCHECKED            187
#define IDB_TOWADA_DROPBUTTON           188
#define IDB_TOWADA_DIALOGBG             189
#define IDB_TOWADA_PROGRESSFG           190
#define IDB_TOWADA_PROGRESSBG           191
#define IDD_REMOTE                      192
#define IDS_WAITING_READY               193
#define IDS_INSERT_DISC                 194
#define IDS_QUICK_BLANK                 195
#define IDS_COMMAND_ERROR               196
#define IDS_READER_                     197
#define IDS_WRITER_                     198
#define IDS_SPEED_                      199
#define IDS_REMAINS_                    200
#define IDS_BUFFER_                     201
#define IDS_CANT_GET_DISC_TYPE          202
#define IDS_CANT_CREATE_MULTISESS_ISO   203
#define IDS_CANT_CREATE_MULTITRACK_ISO  203
#define IDS_READING                     204
#define IDS_CANT_DAO                    205
#define IDS_MIN_FORMAT                  206
#define IDS_FORMATTING                  207
#define IDS_NOT_BLANK                   208
#define IDS_NOT_BLANK_QUICK_BLANK       209
#define IDS_CLOSE_SESSION               210
#define IDS_CLOSE_TRACK                 211
#define IDS_SPINUP                      212
#define IDS_RETRY_                      213
#define IDS_TRACK_                      214
#define IDS_WRITING_LEAD_IN             215
#define IDS_WRITING_CDTEXT              216
#define IDS_CANT_WRITE_CD_DAO           217
#define IDS_SOURCE_IS_BLANK             218
#define IDS_CAPACITY_IS_INSUFFICIENT    219
#define IDS_TOTAL                       220
#define IDS_NETWORK_ERROR_              221
#define IDS_ABORTED                     222
#define IDS_COMPLETE_SUCCESS            223
#define IDS_ERROR_OCCURRED_CMDLOG       224
#define IDS_MEM_ALLOC_ERROR             225
#define IDS_CANT_COPY_DIFFERENT_TYPE    226
#define IDS_CANT_OPEN_IMAGE             227
#define IDS_CANT_READ_IMAGE             228
#define IDS_CANT_WRITE_IMAGE            229
#define IDS_CODE_CONV_ERROR             230
#define IDS_UNKNOWN_COMMAND             231
#define IDS_INVALID_IMAGE_FILE          232
#define IDS_COMPLETE_SUCCESS_AND_EJECT  233
#define IDS_TOTAL_REMAINS_              234
#define IDS_ERROR_OCCURRED_CMDLOG2      235
#define IDS_ERROR_OCCURRED              235
#define IDC_COMBO1                      1000
#define IDC_COMBO2                      1001
#define IDC_PROGRESS1                   1002
#define IDC_PROGRESS2                   1003
#define IDC_STC_BORDER2                 1004
#define IDC_STC_BORDER1                 1005
#define IDC_STC_READER                  1006
#define IDC_STC_WRITER                  1007
#define IDC_STC_PROGRESS1               1008
#define IDC_STC_PROGRESS2               1009
#define IDC_STC_VERSION                 1011
#define IDC_STC_COPYRIGHT               1012
#define IDC_STC_MESSAGE                 1013
#define IDC_BTN_EXTRA                   1014
#define IDC_STC_ICON                    1015
#define IDC_CHK_TESTWRITE               1016
#define IDC_CHK_BUFE                    1017
#define IDC_CHK_ONTHEFLY                1018
#define IDC_CHK_DAO                     1019
#define IDC_CMB_READSPEED               1020
#define IDC_CMB_WRITESPEED              1021
#define IDC_STC_READSPEED               1022
#define IDC_STC_WRITESPEED              1023
#define IDC_STC_TEMPPATH                1024
#define IDC_EDT_TEMPPATH                1025
#define IDC_STC_INFO                    1026
#define IDC_CHK_OUTSIDE                 1026
#define IDC_EDT_ADDRESS                 1027
#define IDC_EDT_PORT                    1028
#define IDC_STC_ADDRESS                 1029
#define IDC_STC_PORT                    1030

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        193
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1031
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif

==> EnbanFukusyaYa-1.20-20101102-src.tar.gz: EnbanFukusyaYa-1.20/Win32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by EnbanFukusya.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDM_THEMESELECT                 0x0020
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_ENBANFUKUSYA_DIALOG         102
#define IDS_DRIVENOTFOUND               102
#define IDS_YES                         103
#define IDS_NO                          104
#define IDS_OK                          105
#define IDS_CANCEL                      106
#define IDS_RETRY                       107
#define IDS_ABORT                       108
#define IDS_IGNORE                      109
#define IDS_COPYSTART                   110
#define IDS_PROCESS_ABORTED             111
#define IDS_PROCESS_SUCCESS             112
#define IDS_PROCESS_ERRSTOP             113
#define IDS_DRIVEINITERROR              114
#define IDS_CREATELOG_ERROR             115
#define IDS_CREATELOG_SUCCESS           116
#define IDS_THEMESELECT                 117
#define IDS_PROCESS_SUCCESS_IMAGE       118
#define IDR_MAINFRAME                   128
#define IDB_LOGO                        129
#define IDB_LOGOMASK                    130
#define IDB_AQUA_BUTTON                 131
#define IDB_AQUA_BUTTONFOCUS            132
#define IDB_AQUA_BUTTONMASK             133
#define IDB_AQUA_PROGRESSBG             134
#define IDB_AQUA_PROGRESSFG             135
#define IDB_AQUA_DROPBUTTON             136
#define IDB_AQUA_DROPBUTTONMASK         137
#define IDB_AQUA_COMBOBOXBG             138
#define IDB_AQUA_CLOSEBUTTON            139
#define IDD_MESSAGEDLG                  139
#define IDB_AQUA_CLOSEBUTTONMASK        140
#define IDB_AQUA_MAXBUTTON              141
#define IDI_APPICON                     141
#define IDB_AQUA_MINBUTTON              142
#define IDI_MSGDLG_STOP                 142
#define IDB_AQUA_TITLEACT               143
#define IDI_MSGDLG_QUESTION             143
#define IDB_AQUA_TITLEINACT             144
#define IDI_MSGDLG_EXCLAMATION          144
#define IDB_AQUA_DIALOGBG               145
#define IDD_SETTING                     145
#define IDB_AQUA_CHECKEDMASK            146
#define IDB_AQUA_CHECKED                147
#define IDB_AQUA_UNCHECKEDMASK          148
#define IDB_AQUA_UNCHECKED              149
#define IDB_BUTTON_NORMAL               150
#define IDB_UNCHECKED                   151
#define IDB_BUTTON_DISABLE              152
#define IDB_BUTTON_FOCUS                153
#define IDB_BUTTON_SELECT               154
#define IDB_CHECKED                     155
#define IDB_DIALOGBG                    157
#define IDB_DROPDOWN                    158
#define IDB_CLOSEBUTTON                 160
#define IDB_COMBOBOX                    162
#define IDB_DROPDOWN_MASK               163
#define IDB_TITLE_INACT                 166
#define IDB_TITLE_ACT                   167
#define IDB_PROGRESSFG                  168
#define IDB_PROGRESSBG                  169
#define IDD_THEMESELECTDLG              170
#define IDB_TOWADA_BUTTON               183
#define IDB_TOWADA_BUTTONFOCUS          184
#define IDB_TOWADA_BUTTONSELECT         185
#define IDB_TOWADA_CHECKED              186
#define IDB_TOWADA_UNCHECKED            187
#define IDB_TOWADA_DROPBUTTON           188
#define IDB_TOWADA_DIALOGBG             189
#define IDB_TOWADA_PROGRESSFG           190
#define IDB_TOWADA_PROGRESSBG           191
#define IDD_REMOTE                      192
#define IDS_WAITING_READY               193
#define IDS_INSERT_DISC                 194
#define IDS_QUICK_BLANK                 195
#define IDS_COMMAND_ERROR               196
#define IDS_READER_                     197
#define IDS_WRITER_                     198
#define IDS_SPEED_                      199
#define IDS_REMAINS_                    200
#define IDS_BUFFER_                     201
#define IDS_CANT_GET_DISC_TYPE          202
#define IDS_CANT_CREATE_MULTISESS_ISO   203
#define IDS_CANT_CREATE_MULTITRACK_ISO  203
#define IDS_READING                     204
#define IDS_CANT_DAO                    205
#define IDS_MIN_FORMAT                  206
#define IDS_FORMATTING                  207
#define IDS_NOT_BLANK                   208
#define IDS_NOT_BLANK_QUICK_BLANK       209
#define IDS_CLOSE_SESSION               210
#define IDS_CLOSE_TRACK                 211
#define IDS_SPINUP                      212
#define IDS_RETRY_                      213
#define IDS_TRACK_                      214
#define IDS_WRITING_LEAD_IN             215
#define IDS_WRITING_CDTEXT              216
#define IDS_CANT_WRITE_CD_DAO           217
#define IDS_SOURCE_IS_BLANK             218
#define IDS_CAPACITY_IS_INSUFFICIENT    219
#define IDS_TOTAL                       220
#define IDS_NETWORK_ERROR_              221
#define IDS_ABORTED                     222
#define IDS_COMPLETE_SUCCESS            223
#define IDS_ERROR_OCCURRED_CMDLOG       224
#define IDS_MEM_ALLOC_ERROR             225
#define IDS_CANT_COPY_DIFFERENT_TYPE    226
#define IDS_CANT_OPEN_IMAGE             227
#define IDS_CANT_READ_IMAGE             228
#define IDS_CANT_WRITE_IMAGE            229
#define IDS_CODE_CONV_ERROR             230
#define IDS_UNKNOWN_COMMAND             231
#define IDS_INVALID_IMAGE_FILE          232
#define IDS_COMPLETE_SUCCESS_AND_EJECT  233
#define IDS_TOTAL_REMAINS_              234
#define IDS_ERROR_OCCURRED_CMDLOG2      235
#define IDS_ERROR_OCCURRED              235
#define IDS_CMDLOG_WAS_SAVED_TO_        236
#define IDS_MKISOFS_ERROR_              237
#define IDS_VIDEO_MODE                  238
#define IDC_COMBO1                      1000
#define IDC_COMBO2                      1001
#define IDC_PROGRESS1                   1002
#define IDC_PROGRESS2                   1003
#define IDC_STC_BORDER2                 1004
#define IDC_STC_BORDER1                 1005
#define IDC_STC_READER                  1006
#define IDC_STC_WRITER                  1007
#define IDC_STC_PROGRESS1               1008
#define IDC_STC_PROGRESS2               1009
#define IDC_STC_VERSION                 1011
#define IDC_STC_COPYRIGHT               1012
#define IDC_STC_MESSAGE                 1013
#define IDC_BTN_EXTRA                   1014
#define IDC_STC_ICON                    1015
#define IDC_CHK_TESTWRITE               1016
#define IDC_CHK_BUFE                    1017
#define IDC_CHK_ONTHEFLY                1018
#define IDC_CHK_DAO                     1019
#define IDC_CMB_READSPEED               1020
#define IDC_CMB_WRITESPEED              1021
#define IDC_STC_READSPEED               1022
#define IDC_STC_WRITESPEED              1023
#define IDC_STC_TEMPPATH                1024
#define IDC_EDT_TEMPPATH                1025
#define IDC_STC_INFO                    1026
#define IDC_CHK_OUTSIDE                 1026
#define IDC_EDT_ADDRESS                 1027
#define IDC_EDT_PORT                    1028
#define IDC_STC_ADDRESS                 1029
#define IDC_STC_PORT                    1030

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        193
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1031
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif
